rnalysis.filtering.DESeqFilter.split\_fold\_change\_direction
=============================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: DESeqFilter.split_fold_change_direction